@@ -12,6 +12,7 @@ Bugreport class which represents a bugreport from the BTS.
 import base64
 from distutils.version import LooseVersion
 import email.feedparser
+import email.policy
 from datetime import datetime
 import os
 import sys
@@ -326,10 +327,12 @@ def get_bug_log(nr):
         # server always returns an empty attachments array ?
         buglog["attachments"] = []
 
-        mail_parser = email.feedparser.FeedParser()
-        mail_parser.feed(buglog["header"])
-        mail_parser.feed("\n\n")
-        mail_parser.feed(buglog["body"])
+        mail_parser = email.feedparser.BytesFeedParser(
+            policy=email.policy.SMTP
+        )
+        mail_parser.feed(buglog["header"].encode())
+        mail_parser.feed("\n\n".encode())
+        mail_parser.feed(buglog["body"].encode())
         buglog["message"] = mail_parser.close()
 
         buglogs.append(buglog)
@@ -383,6 +386,9 @@ def get_bugs(*key_value, **kwargs):
             * "bugs": takes single int or list of bugnumbers, filters the list
                according to given criteria
             * "correspondent": bugs where `correspondent` has sent a mail to
+            * "archive": takes a string: "0" (unarchived), "1"
+              (archived) or "both" (un- and archived). if omitted, only
+              returns un-archived bugs.
 
     Returns
     -------
@@ -444,7 +450,7 @@ def _parse_status(bug_el):
     bug.log_modified = datetime.utcfromtimestamp(float(bug_el('log_modified')))
     bug.tags = [tag for tag in str(bug_el('tags')).split()]
     bug.done = _parse_bool(bug_el('done'))
-    bug.done_by = str(bug_el('done')) if bug.done else None
+    bug.done_by = _parse_string_el(bug_el('done')) if bug.done else None
     bug.archived = _parse_bool(bug_el('archived'))
     bug.unarchived = _parse_bool(bug_el('unarchived'))
     bug.bug_num = int(bug_el('bug_num'))
